@@ -29,8 +29,9 @@ import traceback
 import asyncio
 from contextlib import suppress
 import sys
-import quamash
+import qasync
 from qubesadmin import events
+from qubesadmin import exc
 
 from PyQt5 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
 
@@ -50,8 +51,20 @@ from PyQt5 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
 
 def is_internal(vm):
     """checks if the VM is either an AdminVM or has the 'internal' features"""
-    return (vm.klass == 'AdminVM'
-            or vm.features.get('internal', False))
+    try:
+        return (vm.klass == 'AdminVM'
+                or vm.features.get('internal', False))
+    except exc.QubesDaemonAccessError:
+        return False
+
+
+def is_running(vm, default_state):
+    """Checks if the VM is running, returns default_state if we have
+    insufficient permissions to deteremine that."""
+    try:
+        return vm.is_running()
+    except exc.QubesDaemonAccessError:
+        return default_state
 
 
 def translate(string):
@@ -91,11 +104,18 @@ class SizeSpinBox(QtWidgets.QSpinBox):
         return int(float(value) * multiplier)
 
 
+def get_feature(vm, feature_name, default_value):
+    try:
+        return vm.features.get(feature_name, default_value)
+    except exc.QubesDaemonAccessError:
+        return default_value
+
+
 def get_boolean_feature(vm, feature_name):
     """heper function to get a feature converted to a Bool if it does exist.
     Necessary because of the true/false in features being coded as 1/empty
     string."""
-    result = vm.features.get(feature_name, None)
+    result = get_feature(vm, feature_name, None)
     if result is not None:
         result = bool(result)
     return result
@@ -104,6 +124,8 @@ def get_boolean_feature(vm, feature_name):
 def did_widget_selection_change(widget):
     """a simple heuristic to check if the widget text contains appropriately
     translated 'current'"""
+    if not widget.isEnabled():
+        return False
     return not translate(" (current)") in widget.currentText()
 
 
@@ -164,7 +186,10 @@ def initialize_widget_for_property(
     :return:
     """
     if allow_default:
-        default_property = holder.property_get_default(property_name)
+        try:
+            default_property = holder.property_get_default(property_name)
+        except exc.QubesDaemonAccessError:
+            default_property = "ERROR: unavailable"
         if default_property is None:
             default_property = "none"
         choices.append(
@@ -172,7 +197,12 @@ def initialize_widget_for_property(
              qubesadmin.DEFAULT))
 
     # calculate current (can be default)
-    if holder.property_is_default(property_name):
+    try:
+        is_default = holder.property_is_default(property_name)
+    except exc.QubesDaemonAccessError:
+        is_default = False
+
+    if is_default:
         current_value = qubesadmin.DEFAULT
     else:
         current_value = getattr(holder, property_name)
@@ -484,7 +514,7 @@ def run_asynchronous(window_class):
 
     qubes_app = qubesadmin.Qubes()
 
-    loop = quamash.QEventLoop(qt_app)
+    loop = qasync.QEventLoop(qt_app)
     asyncio.set_event_loop(loop)
     dispatcher = events.EventsDispatcher(qubes_app)
 
