@@ -11,6 +11,12 @@ class QubesVMNotStartedError(BaseException):
 class QubesPropertyAccessError(BaseException):
     pass
 
+class QubesDaemonAccessError(BaseException):
+    pass
+
+class QubesNoSuchPropertyError(BaseException):
+    pass
+
 class QubesDaemonNoResponseError(BaseException):
     pass
 
